@@ -3,7 +3,7 @@ use string_enum::StringEnum;
 use swc_atoms::JsWord;
 use swc_common::{ast_node, EqIgnoreSpan, Span};
 
-use crate::{Ident, Str, TokenAndSpan};
+use crate::{Delimiter, Ident, Str, TokenAndSpan};
 
 #[ast_node("SelectorList")]
 pub struct SelectorList {
@@ -11,6 +11,18 @@ pub struct SelectorList {
     pub children: Vec<ComplexSelector>,
 }
 
+#[ast_node("CompoundSelectorList")]
+pub struct CompoundSelectorList {
+    pub span: Span,
+    pub children: Vec<CompoundSelector>,
+}
+
+#[ast_node("RelativeSelectorList")]
+pub struct RelativeSelectorList {
+    pub span: Span,
+    pub children: Vec<RelativeSelector>,
+}
+
 #[ast_node("ComplexSelector")]
 pub struct ComplexSelector {
     pub span: Span,
@@ -26,6 +38,13 @@ pub enum ComplexSelectorChildren {
     Combinator(Combinator),
 }
 
+#[ast_node("RelativeSelector")]
+pub struct RelativeSelector {
+    pub span: Span,
+    pub combinator: Option<Combinator>,
+    pub selector: ComplexSelector,
+}
+
 /// e.g. `foo.c1.c2`
 #[ast_node("CompoundSelector")]
 pub struct CompoundSelector {
@@ -185,34 +204,49 @@ pub struct AttributeSelectorModifier {
 pub struct PseudoClassSelector {
     pub span: Span,
     pub name: Ident,
-    pub children: Option<Vec<PseudoSelectorChildren>>,
-}
-
-#[ast_node("PseudoElementSelector")]
-pub struct PseudoElementSelector {
-    pub span: Span,
-    pub name: Ident,
-    pub children: Option<Vec<TokenAndSpan>>,
+    pub children: Option<Vec<PseudoClassSelectorChildren>>,
 }
 
 #[ast_node]
-pub enum PseudoSelectorChildren {
-    #[tag("Nth")]
-    Nth(Nth),
-
+pub enum PseudoClassSelectorChildren {
     #[tag("TokenAndSpan")]
     PreservedToken(TokenAndSpan),
+
+    #[tag("AnPlusB")]
+    AnPlusB(AnPlusB),
+
+    #[tag("Ident")]
+    Ident(Ident),
+
+    #[tag("Str")]
+    Str(Str),
+
+    #[tag("Delimiter")]
+    Delimiter(Delimiter),
+
+    #[tag("SelectorList")]
+    SelectorList(SelectorList),
+
+    #[tag("CompoundSelectorList")]
+    CompoundSelectorList(CompoundSelectorList),
+
+    #[tag("RelativeSelectorList")]
+    RelativeSelectorList(RelativeSelectorList),
+
+    #[tag("CompoundSelector")]
+    CompoundSelector(CompoundSelector),
 }
 
-#[ast_node("Nth")]
-pub struct Nth {
-    pub span: Span,
-    pub nth: NthValue,
-    pub selector_list: Option<SelectorList>,
+#[ast_node]
+pub enum AnPlusB {
+    #[tag("Ident")]
+    Ident(Ident),
+    #[tag("AnPlusBNotation")]
+    AnPlusBNotation(AnPlusBNotation),
 }
 
-#[ast_node("AnPlusB")]
-pub struct AnPlusB {
+#[ast_node("AnPlusBNotation")]
+pub struct AnPlusBNotation {
     pub span: Span,
     pub a: Option<i32>,
     pub a_raw: Option<JsWord>,
@@ -220,11 +254,21 @@ pub struct AnPlusB {
     pub b_raw: Option<JsWord>,
 }
 
+#[ast_node("PseudoElementSelector")]
+pub struct PseudoElementSelector {
+    pub span: Span,
+    pub name: Ident,
+    pub children: Option<Vec<PseudoElementSelectorChildren>>,
+}
+
 #[ast_node]
-pub enum NthValue {
-    #[tag("AnPlusB")]
-    AnPlusB(AnPlusB),
+pub enum PseudoElementSelectorChildren {
+    #[tag("TokenAndSpan")]
+    PreservedToken(TokenAndSpan),
 
     #[tag("Ident")]
     Ident(Ident),
+
+    #[tag("CompoundSelector")]
+    CompoundSelector(CompoundSelector),
 }
